@@ -143,12 +143,7 @@ impl Player {
     }
 
     fn _send(&self, event: OutgoingEvent) -> Result<(), NodeSenderError> {
-        #[cfg(feature = "tracing")]
-        tracing::debug!(
-            "sending event on guild player {}: {:?}",
-            self.guild_id,
-            event
-        );
+        tracing::debug!("sending event on guild player {}: {event:?}", self.guild_id);
 
         match &event {
             OutgoingEvent::Pause(event) => self.paused.store(event.pause, Ordering::Release),
